import setuptools 
setuptools.setup(
    name="tn_crypto",
    version="0.1",
    author="Safwen Akrimi",
    description="tn_crypto is crypto graphy symmetric algorithm  symmetric , the key that encrypts a message is the same key that can decrypt them"
"the name of algoritme 'tn_crypto' reference to my country 'TUNISIA'"
"This version support only lowercase character and number and some symbols like [,;:*-]",
packages=setuptools.find_packages(),
classifiers=[
    "Programming Language :: Python :: 3 ",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: MIT License"
]

)
